==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/lt_LT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Serveris - serveris dalinimasis neįjungtas šiame serveryje",
    "The mountpoint name contains invalid characters." : "Prijungimo taškas su neleistinais simboliais.",
    "Not allowed to create a federated share with the same user server" : "Neleidžiama dalintis tarp serverių, nes vartotojas tame pačiame serveryje.",
    "Invalid or untrusted SSL certificate" : "Netinkamas arba nepatikimas SSL sertifikatas",
    "Could not authenticate to remote share, password might be wrong" : "Nepavyko identifikuotis serveryje, gal netinkamas slaptažodis",
    "Storage not valid" : "Saugykla negalioja",
    "Couldn't add remote share" : "Nepavyko pridėti nutolusio dalijimosi",
    "Shared with you" : "Pasidalinta su tavimi",
    "Shared with others" : "Pasidalinta su kitais",
    "Shared by link" : "Pasidalinta su nuoroda",
    "Uploading..." : "Įkeliama...",
    "Nothing shared with you yet" : "Kol kas niekas su tavimi nesidalijama",
    "Files and folders others share with you will show up here" : "Failai ir aplankai kurie dalinami ir tau, bus rodomi čia",
    "Nothing shared yet" : "Niekas nepasidalinta",
    "Files and folders you share will show up here" : "Failai ir aplankai kuriais daliniesi bus rodomi čia",
    "No shared links" : "Nėra pasidalinimų nuoroda",
    "Files and folders you share by link will show up here" : "Failai ir aplankai kuriais daliniesi su nuoroda bus rodomi čia",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar nori pridėti nutolusį dalijimąsi {name} nuo {owner}@{remote}?",
    "Remote share" : "Nutolęs dalinimasis",
    "Remote share password" : "Nutolusio dalijimosi slaptažodis",
    "Cancel" : "Atšaukti",
    "Add remote share" : "Pridėti nutolusi dalijimąsi",
    "You can upload into this folder" : "Gali įkelti į šį aplanką",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nerastas ownCloud (7 ar aukštesnė versiją) {remote} serveryje.",
    "Invalid ownCloud url" : "Neteisinga ownCloud nuoroda",
    "Share" : "Dalintis",
    "Shared by" : "Dalinasi",
    "Sharing" : "Dalijimasis",
    "A file or folder has been <strong>shared</strong>" : "Failas ar aplankas buvo <strong>pasidalintas</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Failas ar aplankas buvo pasidalintas iš <strong>kito serverio</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Viešai pasidalintas failas ar aplankas <strong>parsiųstas</strong>",
    "You received a new remote share %2$s from %1$s" : "Gavote naują nutolusį dalijimąsi %2$s nuo %1$s",
    "You received a new remote share from %s" : "Gavote naują nutolusį dalijimąsi nuo %s",
    "%1$s accepted remote share %2$s" : "%1$s priėmė nutolusį dalijimąsi %2$s",
    "%1$s declined remote share %2$s" : "%1$s atmetė nutolusį dalijimąsi %2$s",
    "%1$s unshared %2$s from you" : "%1$s nebesidalina %2$s su tavimi",
    "Public shared folder %1$s was downloaded" : "Viešas dalijimosi aplankas %1$s parsiųstas",
    "Public shared file %1$s was downloaded" : "Viešai dalinamas failas %1$s parsiųstas",
    "You shared %1$s with %2$s" : "Jūs pasidalinote %1$s su %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s pasidalino %1$s su %3$s",
    "You shared %1$s with group %2$s" : "Jūs pasidalinote %1$s su grupe %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s pasidalino %1$s su grupe %3$s",
    "%2$s shared %1$s via link" : "%2$s pasidalino %1$s nuoroda",
    "You shared %1$s via link" : "Pasidalinote %1$s per nuorodą",
    "%2$s shared %1$s with you" : "%2$s pasidalino %1$s su jumis",
    "Downloaded via public link" : "Atsiųsti per viešą nuorodą",
    "Shared with %2$s" : "Pasidalinta su %2$s",
    "Shared with %3$s by %2$s" : "%2$s pasidalino %3$s",
    "Shared with group %2$s" : "Pasidalinta su grupe %2$s",
    "Shared with group %3$s by %2$s" : "%2$s pasidalino su grupe %3$s",
    "Shared via link by %2$s" : "%2$s pasidalino nuoroda",
    "Shared via public link" : "Pasidalinta vieša nuoroda",
    "Shared by %2$s" : "Pasidalino %2$s",
    "Shares" : "Dalijimaisi",
    "This share is password-protected" : "Turinys apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Netinka slaptažodis: Bandykite dar kartą.",
    "Password" : "Slaptažodis",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Name" : "Pavadinimas",
    "Share time" : "Dalijimosi laikas",
    "Expiration date" : "Galiojimo laikas",
    "Sorry, this link doesn’t seem to work anymore." : "Atleiskite, panašu, kad nuoroda yra neveiksni.",
    "Reasons might be:" : "Galimos priežastys:",
    "the item was removed" : "elementas buvo pašalintas",
    "the link expired" : "baigėsi nuorodos galiojimo laikas",
    "sharing is disabled" : "dalinimasis yra išjungtas",
    "For more info, please ask the person who sent this link." : "Dėl tikslesnės informacijos susisiekite su asmeniu atsiuntusiu nuorodą.",
    "Add to your ownCloud" : "Pridėti prie tavo ownCloud",
    "Download" : "Atsisiųsti",
    "Download %s" : "Atsiųsti %s",
    "Direct link" : "Tiesioginė nuoroda"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/lt_LT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Serveris - serveris dalinimasis neįjungtas šiame serveryje",
    "The mountpoint name contains invalid characters." : "Prijungimo taškas su neleistinais simboliais.",
    "Not allowed to create a federated share with the same user server" : "Neleidžiama dalintis tarp serverių, nes vartotojas tame pačiame serveryje.",
    "Invalid or untrusted SSL certificate" : "Netinkamas arba nepatikimas SSL sertifikatas",
    "Could not authenticate to remote share, password might be wrong" : "Nepavyko identifikuotis serveryje, gal netinkamas slaptažodis",
    "Storage not valid" : "Saugykla negalioja",
    "Couldn't add remote share" : "Nepavyko pridėti nutolusio dalijimosi",
    "Shared with you" : "Pasidalinta su tavimi",
    "Shared with others" : "Pasidalinta su kitais",
    "Shared by link" : "Pasidalinta su nuoroda",
    "Uploading..." : "Įkeliama...",
    "Nothing shared with you yet" : "Kol kas niekas su tavimi nesidalijama",
    "Files and folders others share with you will show up here" : "Failai ir aplankai kurie dalinami ir tau, bus rodomi čia",
    "Nothing shared yet" : "Niekas nepasidalinta",
    "Files and folders you share will show up here" : "Failai ir aplankai kuriais daliniesi bus rodomi čia",
    "No shared links" : "Nėra pasidalinimų nuoroda",
    "Files and folders you share by link will show up here" : "Failai ir aplankai kuriais daliniesi su nuoroda bus rodomi čia",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar nori pridėti nutolusį dalijimąsi {name} nuo {owner}@{remote}?",
    "Remote share" : "Nutolęs dalinimasis",
    "Remote share password" : "Nutolusio dalijimosi slaptažodis",
    "Cancel" : "Atšaukti",
    "Add remote share" : "Pridėti nutolusi dalijimąsi",
    "You can upload into this folder" : "Gali įkelti į šį aplanką",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nerastas ownCloud (7 ar aukštesnė versiją) {remote} serveryje.",
    "Invalid ownCloud url" : "Neteisinga ownCloud nuoroda",
    "Share" : "Dalintis",
    "Shared by" : "Dalinasi",
    "Sharing" : "Dalijimasis",
    "A file or folder has been <strong>shared</strong>" : "Failas ar aplankas buvo <strong>pasidalintas</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Failas ar aplankas buvo pasidalintas iš <strong>kito serverio</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Viešai pasidalintas failas ar aplankas <strong>parsiųstas</strong>",
    "You received a new remote share %2$s from %1$s" : "Gavote naują nutolusį dalijimąsi %2$s nuo %1$s",
    "You received a new remote share from %s" : "Gavote naują nutolusį dalijimąsi nuo %s",
    "%1$s accepted remote share %2$s" : "%1$s priėmė nutolusį dalijimąsi %2$s",
    "%1$s declined remote share %2$s" : "%1$s atmetė nutolusį dalijimąsi %2$s",
    "%1$s unshared %2$s from you" : "%1$s nebesidalina %2$s su tavimi",
    "Public shared folder %1$s was downloaded" : "Viešas dalijimosi aplankas %1$s parsiųstas",
    "Public shared file %1$s was downloaded" : "Viešai dalinamas failas %1$s parsiųstas",
    "You shared %1$s with %2$s" : "Jūs pasidalinote %1$s su %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s pasidalino %1$s su %3$s",
    "You shared %1$s with group %2$s" : "Jūs pasidalinote %1$s su grupe %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s pasidalino %1$s su grupe %3$s",
    "%2$s shared %1$s via link" : "%2$s pasidalino %1$s nuoroda",
    "You shared %1$s via link" : "Pasidalinote %1$s per nuorodą",
    "%2$s shared %1$s with you" : "%2$s pasidalino %1$s su jumis",
    "Downloaded via public link" : "Atsiųsti per viešą nuorodą",
    "Shared with %2$s" : "Pasidalinta su %2$s",
    "Shared with %3$s by %2$s" : "%2$s pasidalino %3$s",
    "Shared with group %2$s" : "Pasidalinta su grupe %2$s",
    "Shared with group %3$s by %2$s" : "%2$s pasidalino su grupe %3$s",
    "Shared via link by %2$s" : "%2$s pasidalino nuoroda",
    "Shared via public link" : "Pasidalinta vieša nuoroda",
    "Shared by %2$s" : "Pasidalino %2$s",
    "Shares" : "Dalijimaisi",
    "This share is password-protected" : "Turinys apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Netinka slaptažodis: Bandykite dar kartą.",
    "Password" : "Slaptažodis",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Name" : "Pavadinimas",
    "Share time" : "Dalijimosi laikas",
    "Expiration date" : "Galiojimo laikas",
    "Sorry, this link doesn’t seem to work anymore." : "Atleiskite, panašu, kad nuoroda yra neveiksni.",
    "Reasons might be:" : "Galimos priežastys:",
    "the item was removed" : "elementas buvo pašalintas",
    "the link expired" : "baigėsi nuorodos galiojimo laikas",
    "sharing is disabled" : "dalinimasis yra išjungtas",
    "For more info, please ask the person who sent this link." : "Dėl tikslesnės informacijos susisiekite su asmeniu atsiuntusiu nuorodą.",
    "Add to your ownCloud" : "Pridėti prie tavo ownCloud",
    "Download" : "Atsisiųsti",
    "Download %s" : "Atsiųsti %s",
    "Direct link" : "Tiesioginė nuoroda",
    "Pending" : "Laukiantis",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Declined" : "Atmesta"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
